@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Moose;
 
@@ -54,7 +54,7 @@ sub before_build {
     my $self = shift;
 
     for my $file ( keys %files ) {
-        next if -f $file;
+        next if -e $file;
 
         open my $fh, '>:encoding(UTF-8)', $file;
         print {$fh} $files{$file}
@@ -91,7 +91,7 @@ Dist::Zilla::Plugin::DROLSKY::Contributors - Creates a weaver.ini and .mailmap t
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =for Pod::Coverage .*
 
