@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Parse::PMFile;
 
@@ -21,7 +21,7 @@ sub provide_version {
     ( my $module = $self->zilla->name ) =~ s{-}{/}g;
     my $file = "lib/$module.pm";
     $self->log_fatal("Cannot find $file to get \$VERSION from")
-        unless -f $file;
+        unless -e $file;
 
     my ( $info, $e ) = Parse::PMFile->new->parse($file);
     ( my $package = $self->zilla->name ) =~ s/-/::/g;
@@ -49,7 +49,7 @@ Dist::Zilla::Plugin::DROLSKY::VersionProvider - Gets the distribution version fr
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =for Pod::Coverage .*
 
